@@ -44,6 +44,8 @@ const string SyntaxReader::REGEX_ESCSEQ =
 
 DelimiterMap SyntaxReader::nestedStateEndDelimiters;
 
+DelimiterMap SyntaxReader::pluginConfigOverride;
+
 AllowInnerSectionsMap SyntaxReader::allowInnerSections;
 
 vector<Diluculum::LuaFunction*> SyntaxReader::pluginChunks;
@@ -204,7 +206,17 @@ LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginR
             }
             idx++;
         }
-
+        
+        if (globals.count("GeneratorOverride")) {
+            idx=1;
+            Diluculum::LuaValue lVal = ls["GeneratorOverride"][idx].value();
+            while (lVal !=Diluculum::Nil) {
+                pluginConfigOverride[StringTools::change_case(lVal["Param"].asString())] = lVal["Value"].asString();
+                idx++;
+                lVal = ls["GeneratorOverride"][idx].value();
+            }
+        }
+        
         if (globals.count("Comments")) {
 
             int listIdx=1;
